clear all
close all
clc

% Datos de la tabla... (Como que este paso es casi mecanico)
W = [57.6;109.2;199.7;300.2;355.2;420.1;535.7;743.3];
C = [5.3;13.7;38.3;78.1;104.5;135.0;195.6;319.2];

% Modelo 1 se puede re-escribir como log(C1/W) = log(alpha) + beta*W
A1 = [ones(size(W)), W];
b1 = log(C./W);

% Resolver sistema
x1 = A1\b1;

norm(b1 - A1*x1)

% Encontrar coeficientes
alpha1 = exp(x1(1));
beta1 = x1(2);

% Modelo 2 se puede reescribir como log(1000/C2 - 1) = log(alpha) + beta*W
A2 = [ones(size(W)), W];
b2 = log(1000./C - 1);

% Resolver sistema
x2 = A2\b2;

norm(b2 - A2*x2)

% Encontrar coeficientes
alpha2 = exp(x2(1));
beta2 = x2(2);

% Graficar
WW = linspace(min(W), max(W), 200);

plot(W, C, '*k'); hold on
plot(WW, alpha1*WW.*exp(beta1*WW), 'r')
plot(WW, 1000./(1 + alpha2*exp(beta2*WW)), 'b')
legend('Datos', 'Modelo C1', 'Modelo C2')
xlabel('Peso Cuerpo [mg]')
ylabel('Peso Pinza [mg]')

% Basados en los errores el "mejor" modelo es C1.
C_300 = alpha1*300*exp(beta1*300);
C_800 = alpha1*800*exp(beta1*800);

disp('Valores para W = 300 y W = 800')
disp(C_300)
disp(C_800)


